@@ -12,6 +12,7 @@ import ipdb
 import six
 from six.moves import configparser
 from six.moves.urllib import parse
+from verlib import NormalizedVersion
 
 from . import utils
 from .exceptions import (
@@ -480,6 +481,11 @@ def main():
             "any version of Python 3.  Please upgrade your version of "
             "python before using Jirafs."
         )
+    if utils.get_git_version() < NormalizedVersion('1.8'):
+        raise RuntimeError(
+            "Jirafs requires minimally version 1.8 of Git.  Please "
+            "upgrade your version of git before using Jirafs."
+        )
 
     parser = argparse.ArgumentParser(
         description='Edit Jira issues locally from your filesystem',
